def get_api_module():
    api_modules = (
        "model2.user.main.Service",
        "model2.role.main.Service"
    )
    return api_modules